# Table of Contents

- [publishing-custom-reports-on-sap-leanix-store](<./publishing-custom-reports-on-sap-leanix-store.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Publishing Custom Reports on the SAP LeanIX Store](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store.md>)
  - [Getting Started with the SAP LeanIX Store](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Getting-Started-with-the-SAP-LeanIX-Store.md>)
  - [Publishing Process](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Publishing-Process.md>)
  - [Review Criteria](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Review-Criteria.md>)
  - [Step 1: Register as a Publisher](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Step-1-Register-as-a-Publisher.md>)
  - [Step 2: Create a Report](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Step-2-Create-a-Report.md>)
  - [Step 3: Initiate the Review Process](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Step-3-Initiate-the-Review-Process.md>)
  - [Step 4: Create New Report Versions](<./Publishing-Custom-Reports-on-the-SAP-LeanIX-Store/Step-4-Create-New-Report-Versions.md>)
